import { GraphQLWorker } from './GraphQLWorker';
import type { MonacoGraphQLAPI } from './api';
import type { Uri, Position, Thenable, CancellationToken } from 'monaco-editor';
import * as monaco from 'monaco-editor';
import { editor } from 'monaco-editor/esm/vs/editor/editor.api';
import { CompletionItemKind as lsCompletionItemKind } from 'graphql-language-service';
import { GraphQLWorkerCompletionItem } from './utils';
export interface WorkerAccessor {
    (...more: Uri[]): Thenable<GraphQLWorker>;
}
export declare class DiagnosticsAdapter {
    private defaults;
    private _worker;
    private _disposables;
    private _listener;
    constructor(defaults: MonacoGraphQLAPI, _worker: WorkerAccessor);
    dispose(): void;
    private _doValidate;
}
export declare function toCompletionItemKind(kind: lsCompletionItemKind): monaco.languages.CompletionItemKind;
export declare function toCompletion(entry: GraphQLWorkerCompletionItem): monaco.languages.CompletionItem;
export declare class CompletionAdapter implements monaco.languages.CompletionItemProvider {
    private _worker;
    constructor(_worker: WorkerAccessor);
    get triggerCharacters(): string[];
    provideCompletionItems(model: editor.IReadOnlyModel, position: Position, _context: monaco.languages.CompletionContext, _token: CancellationToken): Promise<monaco.languages.CompletionList>;
}
export declare class DocumentFormattingAdapter implements monaco.languages.DocumentFormattingEditProvider {
    private _worker;
    constructor(_worker: WorkerAccessor);
    provideDocumentFormattingEdits(document: editor.ITextModel, _options: monaco.languages.FormattingOptions, _token: CancellationToken): Promise<{
        range: monaco.Range;
        text: string;
    }[]>;
}
export declare class HoverAdapter implements monaco.languages.HoverProvider {
    private _worker;
    constructor(_worker: WorkerAccessor);
    provideHover(model: editor.IReadOnlyModel, position: Position, _token: CancellationToken): Promise<monaco.languages.Hover>;
    dispose(): void;
}
//# sourceMappingURL=languageFeatures.d.ts.map